@@ -63,8 +63,10 @@ struct _GSockAddrFuncs
 gchar *g_sockaddr_format(GSockAddr *a, gchar *text, gulong n, gint format);
 guint16 g_sockaddr_get_port(GSockAddr *a);
 void g_sockaddr_set_port(GSockAddr *a, guint16 port);
+guint8 *g_sockaddr_get_address(GSockAddr *self, guint8 *buffer, socklen_t buffer_size);
 
 GSockAddr *g_sockaddr_new(struct sockaddr *sa, int salen);
+GSockAddr *g_sockaddr_new_from_peer_fd(gint fd);
 GSockAddr *g_sockaddr_ref(GSockAddr *a);
 void g_sockaddr_unref(GSockAddr *a);
 
